@@ -141,7 +141,7 @@ int (*XvScreenInitProc)(ScreenPtr) = XvScreenInit;
 static xf86XVInitGenericAdaptorPtr *GenDrivers = NULL;
 static int NumGenDrivers = 0;
 
-int
+_X_EXPORT int
 xf86XVRegisterGenericAdaptorDriver(
     xf86XVInitGenericAdaptorPtr InitFunc
 ){
@@ -158,7 +158,7 @@ xf86XVRegisterGenericAdaptorDriver(
   return 1;
 }
 
-int
+_X_EXPORT int
 xf86XVListGenericAdaptors(
     ScrnInfoPtr pScrn,
     XF86VideoAdaptorPtr **adaptors
@@ -197,7 +197,7 @@ typedef struct {
 
 static OffscreenImageRec OffscreenImages[MAXSCREENS];
 
-Bool
+_X_EXPORT Bool
 xf86XVRegisterOffscreenImages(
     ScreenPtr pScreen,
     XF86OffscreenImagePtr images,
@@ -209,7 +209,7 @@ xf86XVRegisterOffscreenImages(
     return TRUE;
 }
 
-XF86OffscreenImagePtr
+_X_EXPORT XF86OffscreenImagePtr
 xf86XVQueryOffscreenImages(
    ScreenPtr pScreen,
    int *num
@@ -219,20 +219,20 @@ xf86XVQueryOffscreenImages(
 }
 
 
-XF86VideoAdaptorPtr
+_X_EXPORT XF86VideoAdaptorPtr
 xf86XVAllocateVideoAdaptorRec(ScrnInfoPtr pScrn)
 {
     return xcalloc(1, sizeof(XF86VideoAdaptorRec));
 }
 
-void
+_X_EXPORT void
 xf86XVFreeVideoAdaptorRec(XF86VideoAdaptorPtr ptr)
 {
     xfree(ptr);
 }
 
 
-Bool
+_X_EXPORT Bool
 xf86XVScreenInit(
    ScreenPtr pScreen,
    XF86VideoAdaptorPtr *adaptors,
@@ -687,8 +687,6 @@ xf86XVCopyClip(
    XvPortRecPrivatePtr portPriv,
    GCPtr pGC
 ){
-    ScreenPtr pScreen = pGC->pScreen;
-
     /* copy the new clip if it exists */
     if((pGC->clientClipType == CT_REGION) && pGC->clientClip) {
 	if(!portPriv->clientClip)
@@ -750,7 +748,8 @@ xf86XVRegetVideo(XvPortRecPrivatePtr portPriv)
 			WinBox.x1, WinBox.y1,
 			portPriv->vid_w, portPriv->vid_h,
 			portPriv->drw_w, portPriv->drw_h,
-			&ClipRegion, portPriv->DevPriv.ptr);
+			&ClipRegion, portPriv->DevPriv.ptr,
+			portPriv->pDraw);
 
   if(ret == Success)
 	portPriv->isOn = XV_ON;
@@ -841,7 +840,8 @@ xf86XVReputVideo(XvPortRecPrivatePtr portPriv)
 			WinBox.x1, WinBox.y1,
 			portPriv->vid_w, portPriv->vid_h,
 			portPriv->drw_w, portPriv->drw_h,
-			&ClipRegion, portPriv->DevPriv.ptr);
+			&ClipRegion, portPriv->DevPriv.ptr,
+			portPriv->pDraw);
 
   if(ret == Success) portPriv->isOn = XV_ON;
 
@@ -927,7 +927,8 @@ xf86XVReputImage(XvPortRecPrivatePtr portPriv)
 
   ret = (*portPriv->AdaptorRec->ReputImage)(portPriv->pScrn,
 			WinBox.x1, WinBox.y1,
-			&ClipRegion, portPriv->DevPriv.ptr);
+			&ClipRegion, portPriv->DevPriv.ptr,
+			portPriv->pDraw);
 
   portPriv->isOn = (ret == Success) ? XV_ON : XV_OFF;
 
@@ -1473,7 +1474,8 @@ xf86XVPutStill(
   ret = (*portPriv->AdaptorRec->PutStill)(portPriv->pScrn,
 		vid_x, vid_y, WinBox.x1, WinBox.y1,
 		vid_w, vid_h, drw_w, drw_h,
-		&ClipRegion, portPriv->DevPriv.ptr);
+		&ClipRegion, portPriv->DevPriv.ptr,
+		pDraw);
 
   if((ret == Success) &&
 	(portPriv->AdaptorRec->flags & VIDEO_OVERLAID_STILLS)) {
@@ -1601,7 +1603,8 @@ xf86XVGetStill(
   ret = (*portPriv->AdaptorRec->GetStill)(portPriv->pScrn,
 		vid_x, vid_y, WinBox.x1, WinBox.y1,
 		vid_w, vid_h, drw_w, drw_h,
-		&ClipRegion, portPriv->DevPriv.ptr);
+		&ClipRegion, portPriv->DevPriv.ptr,
+		pDraw);
 
 GET_STILL_BAILOUT:
 
@@ -1773,7 +1776,8 @@ xf86XVPutImage(
   ret = (*portPriv->AdaptorRec->PutImage)(portPriv->pScrn,
 		src_x, src_y, WinBox.x1, WinBox.y1,
 		src_w, src_h, drw_w, drw_h, format->id, data, width, height,
-		sync, &ClipRegion, portPriv->DevPriv.ptr);
+		sync, &ClipRegion, portPriv->DevPriv.ptr,
+		pDraw);
 
   if((ret == Success) &&
 	(portPriv->AdaptorRec->flags & VIDEO_OVERLAID_IMAGES)) {
@@ -1819,7 +1823,7 @@ xf86XVQueryImageAttributes(
 			format->id, width, height, pitches, offsets);
 }
 
-void
+_X_EXPORT void
 xf86XVFillKeyHelper (ScreenPtr pScreen, CARD32 key, RegionPtr clipboxes)
 {
    XF86XVScreenPtr ScreenPriv = GET_XF86XV_SCREEN(pScreen);
@@ -1871,7 +1875,7 @@ xf86XVFillKeyHelper (ScreenPtr pScreen, CARD32 key, RegionPtr clipboxes)
 
 #define DummyScreen screenInfo.screens[0]
 
-Bool
+_X_EXPORT Bool
 xf86XVClipVideoHelper(
     BoxPtr dst,
     INT32 *xa,
@@ -1953,7 +1957,7 @@ xf86XVClipVideoHelper(
     return TRUE;
 }
 
-void
+_X_EXPORT void
 xf86XVCopyYUV12ToPacked(
     const void *srcy,
     const void *srcv,
@@ -2011,7 +2015,7 @@ xf86XVCopyYUV12ToPacked(
     }
 }
 
-void
+_X_EXPORT void
 xf86XVCopyPacked(
     const void *src,
     void *dst,
